@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 '''
 
-__version__ = '3.1.0'
+__version__ = '3.1.7'
 __author__ = 'Charles Cazabon <getmail @ discworld.dyndns.org>'
 
 #
@@ -152,7 +152,7 @@ class getmail:
         if not self.conf['message_log']:
             return
         msg = res['percent'].sub ('%%', msg) % self.conf
-        ts = time.strftime ('%d %b %Y %H:%M:%S ', time.localtime (time.time ()))
+        ts = time.strftime ('%d %b %Y %H:%M:%S ', time.gmtime (time.time ()))
         self.logfile.write (ts + msg + '\n')
         self.logfile.flush ()
 
@@ -256,7 +256,7 @@ class getmail:
         self.msglog ('STAT: %i messages %i octets' % (msgs, octets))
 
     ###################################
-    def process_msg (self, msg, msgnum):
+    def process_msg (self, msg, msgnum, msgcount, msgsize):
         '''Process retrieved message and deliver to appropriate recipients.'''
         mess = getmailMessage (msg)
         if self.conf['use_*env']:
@@ -292,21 +292,7 @@ class getmail:
             pass
 
         msgid = mess.get ('message-id', 'None')
-        self.msglog ('New msg "%s" from "%s"' % (msgid, env_sender))
-
-        # Filter message if user wants to
-        filters = self.conf['message_filter']
-        if filters:
-            if type (filters) != ListType:
-                filters = [filters]
-            for _filter in filters:
-                rc, newmsg = self.filter_message (msg, _filter)
-                if rc == 99:
-                    self.logfunc (INFO, 'message dropped because filter "%s" exited 99\n' % _filter)
-                    return -1
-                if rc != 0:
-                    raise getmailDeliveryException, 'message filter "%s" exited %s\n' % (_filter, rc)
-                msg = newmsg
+        self.msglog ('New msg %i/%i len %s id "%s" from "%s"' % (msgnum, msgcount, msgsize, msgid, env_sender))
 
         count = 0
         if len (self.users):
@@ -415,7 +401,8 @@ class getmail:
             import popen2
 
             popen2._cleanup()
-            cmd = popen2.Popen3 (command, 1, bufsize=-1)
+            #cmd = popen2.Popen3 (command, 1, bufsize=-1)
+            cmd = popen2.Popen3 (command, 1, bufsize=512)
             cmdout, cmdin, cmderr = cmd.fromchild, cmd.tochild, cmd.childerr
             cmdin.write (fromline)
             cmdin.write (string.replace (msg, line_end['pop3'], line_end['mbox']))
@@ -593,7 +580,7 @@ class getmail:
 
                     try:
                         # Find recipients for this message and deliver to them.
-                        count = self.process_msg (msg, msgnum)
+                        count = self.process_msg (msg, msgnum, len (self.msglist) - 1, msglen)
                         if count == -1:
                             pass
                         elif count == 0:
